@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::Old::Module;
 # ABSTRACT: module that has a newer version available
-$App::Magpie::Action::Old::Module::VERSION = '2.003';
+$App::Magpie::Action::Old::Module::VERSION = '2.004';
 use File::ShareDir::PathClass;
 use Moose;
 use MooseX::Has::Sugar;
@@ -100,8 +100,8 @@ sub category {
     return "strange" if scalar(@pkgs) >= 2;
     # scalar(@pkgs) == 1;
     return "ignored"    if exists $SKIPPKG{ $pkgs[0]->name };
-    return "confused"   if $self->oldver == $self->newver; # cpan can be confused
     return "null"       if $self->oldver == 0 || $self->newver == 0;
+    return "nodiff"     if $self->oldver == $self->newver; # cpan can be confused
     return "unparsable" if $self->oldver eq "Unparsable";
     return "normal";
 }
@@ -122,7 +122,7 @@ App::Magpie::Action::Old::Module - module that has a newer version available
 
 =head1 VERSION
 
-version 2.003
+version 2.004
 
 =head1 DESCRIPTION
 
@@ -173,7 +173,7 @@ Return the module category:
 
 =item * C<strange> - shipped by more than one non-core package
 
-=item * C<confused> - when cpan reports a difference although there isn't
+=item * C<nodiff> - when cpan reports a difference although there isn't
 
 =item * C<null> - when old or new versions are 0.0000
 
